@@ -12,6 +12,7 @@ import pathlib
 import warnings
 from decimal import Decimal
 from motus import Funciones_Auxiliares as fa
+from motus import Series_Tiempo as st
 
 warnings.filterwarnings("error")
 
@@ -921,6 +922,7 @@ class Experimento:
     def grafica(self, grafica, lim_inf_x=None, lim_sup_x=None, lim_inf_y=None, lim_sup_y=None,
                 tamanio_vectores=100, brinco_temporal=int(1), consencuencia_elegida=None,
                 tamanio_volumenes=24, div_volumenes=2, tipo_grafica_volumen="cilindros",
+                arreglo_series_tiempo=None, brincos_series_tiempo=1, longitud_series_tiempo=1,
                 arreglo_grafica_distancias=[True, True, True, True],
                 rotacion_grafica_3d=220):
 
@@ -1236,6 +1238,24 @@ class Experimento:
         #    plt.grid(False)
         #    plt.colorbar(
         #        plt.imshow(np.flipud(self.matriz_cuadriculada)))
+        elif grafica == 'regresion_lineal':
+            print("Entro a regresión lineal")
+
+            if arreglo_series_tiempo == None:
+                print("No se ha seleccionado un arreglo a procesar")
+
+            else:
+
+                indices_tiempo, series_tiempo = st.generar_series_tiempo(lista_a_procesar= arreglo_series_tiempo,
+                                                                         brinco_temporal=brinco_temporal,
+                                                                         longitud_ventana_tiempo=longitud_series_tiempo)
+
+                resultados = st.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
+                                                                            series_tiempo=series_tiempo)
+
+                for indice in range(0, len(indices_tiempo)):
+                    plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue')
+                    plt.plot(indices_tiempo[indice], resultados[indice], color='red')
 
         elif grafica == 'cilindros_objetos_importantes':
             print("Entro a volumenes_objetos_importantes")
